@@ -6,8 +6,8 @@ import glob
 from pathlib import Path
 import jinja2
 from dsocli.logger import Logger
-from dsocli.config import Config
-from dsocli.providers import ProviderManager
+from dsocli.config import Configs
+from dsocli.providers import Providers
 from dsocli.templates import Templates, TemplateProvider
 from dsocli.stages import Stages
 from dsocli.constants import *
@@ -15,7 +15,7 @@ from dsocli.exceptions import DSOException
 
 
 _settings = {
-    'templates_dir' : '{0}/templates'.format(Config.config_dir),
+    'templates_dir' : '{0}/templates'.format(Configs.config_dir),
 }
 
 _default_spec = {
@@ -34,7 +34,7 @@ class LocalTemplateProvider(TemplateProvider):
 
     @property
     def templates_root_path(self):
-        return f"{Config.working_dir}/{_settings['templates_dir']}"
+        return f"{Configs.working_dir}/{_settings['templates_dir']}"
 
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
@@ -99,4 +99,4 @@ class LocalTemplateProvider(TemplateProvider):
 ###--------------------------------------------------------------------------------------------
 ###--------------------------------------------------------------------------------------------
 
-ProviderManager.register(LocalTemplateProvider())
+Providers.register(LocalTemplateProvider())
